@@ -9,11 +9,13 @@ __email__ = "arenas.guerrero.julian@outlook.com"
 import errno
 import os
 import logging
+import multiprocessing as mp
 
 from configparser import ConfigParser
+from pathlib import Path
 
 from .constants import *
-from .utils import get_valid_dir_path, get_valid_file_name, get_valid_file_path, remove_file_extension
+from .utils import get_valid_file_name, get_valid_file_path
 
 
 CONFIGURATION_SECTION = 'CONFIGURATION'
@@ -61,6 +63,33 @@ MAPPINGS = 'mappings'
 DATABASE_URL = 'db_url'
 
 
+##############################################################################
+########################   ARGUMENTS DEFAULT VALUES   ########################
+##############################################################################
+
+DEFAULT_OUTPUT_DIR = 'output'
+DEFAULT_OUTPUT_FILE = 'result'
+DEFAULT_OUTPUT_FORMAT = NQUADS
+DEFAULT_CLEAN_OUTPUT_DIR = 'no'
+DEFAULT_SAFE_PERCENT_ENCODING = ''
+DEFAULT_LOGGING_FILE = ''
+DEFAULT_LOGGING_LEVEL = 'INFO'
+DEFAULT_INFER_SQL_DATATYPES = 'no'
+DEFAULT_NUMBER_OF_PROCESSES = 2 * mp.cpu_count()
+DEFAULT_CHUNKSIZE = 100000
+DEFAULT_NA_FILTER = 'yes'
+DEFAULT_NA_VALUES = ',#N/A,N/A,#N/A N/A,n/a,NA,<NA>,#NA,NULL,null,NaN,nan,None'
+DEFAULT_ONLY_PRINTABLE_CHARACTERS = 'no'
+
+# ORACLE
+DEFAULT_ORACLE_CLIENT_LIB_DIR = ''
+DEFAULT_ORACLE_CLIENT_CONFIG_DIR = ''
+
+# DEVELOPMENT OPTIONS
+DEFAULT_READ_PARSED_MAPPINGS_PATH = ''
+DEFAULT_WRITE_PARSED_MAPPINGS_PATH = ''
+
+
 ##############################################################################
 ########################   PARAMETERS DEFAULT VALUES   #######################
 ##############################################################################
@@ -78,7 +107,6 @@ CONFIGURATION_OPTIONS_EMPTY_VALID = {
             ORACLE_CLIENT_CONFIG_DIR: DEFAULT_ORACLE_CLIENT_LIB_DIR,
         }
 
-
 # input parameters that are to be replaced with the default vale if they are empty
 CONFIGURATION_OPTIONS_EMPTY_NON_VALID = {
             OUTPUT_DIR: DEFAULT_OUTPUT_DIR,
@@ -86,7 +114,7 @@ CONFIGURATION_OPTIONS_EMPTY_NON_VALID = {
             CLEAN_OUTPUT_DIR: DEFAULT_CLEAN_OUTPUT_DIR,
             ONLY_PRINTABLE_CHARACTERS: DEFAULT_ONLY_PRINTABLE_CHARACTERS,
             INFER_SQL_DATATYPES: DEFAULT_INFER_SQL_DATATYPES,
-            CHUNKSIZE: DEFAULT_CHUNKSIZE,
+            CHUNKSIZE: 100000,
             LOGGING_LEVEL: DEFAULT_LOGGING_LEVEL,
             NA_FILTER: DEFAULT_NA_FILTER,
             NUMBER_OF_PROCESSES: DEFAULT_NUMBER_OF_PROCESSES
@@ -136,8 +164,7 @@ class Config(ConfigParser):
                 self.set(self.configuration_section, configuration_option, str(configuration_option_default))
 
     def validate_configuration_section(self):
-        # OUTPUT DIR & FILE, WRITE PARSED MAPPINGS FILE, LOGS FILE
-        self.set_output_dir(get_valid_dir_path(self.get_output_dir()))
+        # OUTPUT FILE, WRITE PARSED MAPPINGS FILE, LOGS FILE
         self.set_output_file(get_valid_file_name(self.get_output_file()))
         self.set_parsed_mappings_write_path(get_valid_file_path(self.get_parsed_mappings_write_path()))
         self.set_logging_file(get_valid_file_path(self.get_logging_file()))
@@ -146,15 +173,15 @@ class Config(ConfigParser):
         output_format = str(self.get_output_format()).upper()
         self.set_output_format(output_format)
         if output_format not in VALID_OUTPUT_FORMATS:
-            raise ValueError(OUTPUT_FORMAT + ' value `' + self.get_output_format() +
-                             '` is not valid. It must be in: ' + str(VALID_OUTPUT_FORMATS) + '.')
+            raise ValueError(f'{OUTPUT_FORMAT} value `{self.get_output_format()}` is not valid. '
+                             f'It must be in: {VALID_OUTPUT_FORMATS}.')
 
         # LOGGING LEVEL
         logging_level = str(self.get_logging_level()).upper()
         self.set_logging_level(logging_level)
         if logging_level not in VALID_LOGGING_LEVEL:
-            raise ValueError(LOGGING_LEVEL + ' value `' + self.get_logging_level() +
-                             '` is not valid. It must be in: ' + str(VALID_LOGGING_LEVEL) + '.')
+            raise ValueError(f'{LOGGING_LEVEL} value `{self.get_logging_level()}` is not valid. '
+                             f'It must be in: {VALID_LOGGING_LEVEL}.')
 
         # MAPPING PARTITIONING
         mapping_partitioning = str(self.get_mapping_partition()).upper()
@@ -162,15 +189,14 @@ class Config(ConfigParser):
         if mapping_partitioning not in NO_PARTITIONING + [PARTIAL_AGGREGATIONS_PARTITIONING] + [
                 MAXIMAL_PARTITIONING]:
             raise ValueError(
-                MAPPING_PARTITION + ' value `' + self.get_mapping_partition() + '` is not valid. It must be in: ' + str(
-                    [MAXIMAL_PARTITIONING] + [
-                        PARTIAL_AGGREGATIONS_PARTITIONING] + NO_PARTITIONING) + '.')
+                f'{MAPPING_PARTITION} value `{self.get_mapping_partition()}` is not valid. '
+                f'It must be in: {[MAXIMAL_PARTITIONING] + [PARTIAL_AGGREGATIONS_PARTITIONING] + NO_PARTITIONING}.')
 
     def log_config_info(self):
-        logging.debug('CONFIGURATION: ' + str(dict(self.items(self.configuration_section))))
+        logging.debug(f'CONFIGURATION: {dict(self.items(self.configuration_section))}')
 
         for data_source_section in self.get_data_sources_sections():
-            logging.debug('DATA SOURCE `' + data_source_section + '`: ' + str(dict(self.items(data_source_section))))
+            logging.debug(f'DATA SOURCE `{data_source_section}`: {dict(self.items(data_source_section))}')
 
     #################################################################################
     #######################   CONFIGURATION SECTION METHODS   #######################
@@ -186,28 +212,16 @@ class Config(ConfigParser):
         return self.getint(self.configuration_section, NUMBER_OF_PROCESSES) > 1
 
     def is_read_parsed_mappings_file_provided(self):
-        if self.get(self.configuration_section, READ_PARSED_MAPPINGS_PATH):
-            return True
-        else:
-            return False
+        return bool(self.get(self.configuration_section, READ_PARSED_MAPPINGS_PATH))
 
     def is_write_parsed_mappings_file_provided(self):
-        if self.get(self.configuration_section, WRITE_PARSED_MAPPINGS_PATH):
-            return True
-        else:
-            return False
+        return bool(self.get(self.configuration_section, WRITE_PARSED_MAPPINGS_PATH))
 
     def is_oracle_client_lib_dir_provided(self):
-        if self.get(self.configuration_section, ORACLE_CLIENT_LIB_DIR):
-            return True
-        else:
-            return False
+        return bool(self.get(self.configuration_section, ORACLE_CLIENT_LIB_DIR))
 
     def is_oracle_client_config_dir_provided(self):
-        if self.get(self.configuration_section, ORACLE_CLIENT_CONFIG_DIR):
-            return True
-        else:
-            return False
+        return bool(self.get(self.configuration_section, ORACLE_CLIENT_CONFIG_DIR))
 
     def infer_sql_datatypes(self):
         return self.getboolean(self.configuration_section, INFER_SQL_DATATYPES)
@@ -274,19 +288,19 @@ class Config(ConfigParser):
 
     def get_output_file_path(self, mapping_partition=None):
         if self.get_output_file():
-            file_path = os.path.join(self.get_output_dir(), self.get_output_file())
-            # remove file extension, we will set it based on the output format
-            file_path = remove_file_extension(file_path)
+            file_name = self.get_output_file()
         elif mapping_partition:
-            file_path = os.path.join(self.get_output_dir(), mapping_partition)
+            file_name = mapping_partition
         else:
             # neither output_file was specified nor mapping partition are used. Use default output_file.
-            file_path = os.path.join(self.get_output_dir(), OUTPUT_FILE)
+            file_name = OUTPUT_FILE
 
-        # add file extension
-        file_path += OUTPUT_FORMAT_FILE_EXTENSION[self.get_output_format()]
+        file_extension = OUTPUT_FORMAT_FILE_EXTENSION[self.get_output_format()]
 
-        return file_path
+        # if filename already has a suffix, with_suffix() will replace it with the new suffix
+        file_path = Path(self.get_output_dir(), file_name).with_suffix(file_extension)
+
+        return file_path.as_posix()
 
     def set_mapping_partition(self, mapping_partitioning):
         self.set(self.configuration_section, MAPPING_PARTITION, mapping_partitioning.upper())
