@@ -19,6 +19,7 @@ from ..utils import normalize_hierarchical_data
 
 
 def get_file_data(config, mapping_rule, references):
+    references = list(references)
     file_source_type = mapping_rule['source_type']
 
     if file_source_type in [CSV, TSV]:
@@ -42,7 +43,7 @@ def get_file_data(config, mapping_rule, references):
     elif file_source_type == XML:
         return _read_xml(mapping_rule, references)
     else:
-        raise ValueError('Found an invalid source type. Found value `' + file_source_type + '`.')
+        raise ValueError(f'Found an invalid source type. Found value `{file_source_type}`.')
 
 
 def _read_csv(config, mapping_rule, references, file_source_type):
@@ -138,15 +139,15 @@ def _read_json(mapping_rule, references):
     jsonpath_expression = jsonpath_expression[:-1] + ')'
 
     jsonpath_result = JSONPath(jsonpath_expression).parse(json_data)
-    json_df = pd.json_normalize([json_object for json_object in normalize_hierarchical_data(jsonpath_result)])
+    # normalize and remove nulls
+    json_df = pd.json_normalize([json_object for json_object in normalize_hierarchical_data(jsonpath_result) if None not in json_object.values()])
 
     # add columns with null values for those references in the mapping rule that are not present in the data file
     missing_references_in_df = list(set(references).difference(set(json_df.columns)))
     json_df[missing_references_in_df] = np.nan
 
-    # keep only reference columns in the dataframe and remove NULLs
+    # keep only reference columns in the dataframe
     json_df = json_df[references]
-    json_df.dropna(axis=0, how='any', inplace=True)
 
     return [json_df]
 
