@@ -94,30 +94,30 @@ def _get_column_table_datatype(config, source_name, table_name, column_name):
     db_connection, db_dialect = _relational_db_connection(config, source_name)
 
     if db_dialect == ORACLE:
-        # Oracle does not use the standard INFORMATION_SCHEMA
-        sql_query = "SELECT t.data_type FROM all_tab_columns t WHERE t.TABLE_NAME = '" + table_name + \
-                    "' AND t.COLUMN_NAME='" + column_name + "'"
+        sql_query = f"SELECT t.data_type FROM all_tab_columns t " \
+                    f"WHERE t.TABLE_NAME = '{table_name}' AND t.COLUMN_NAME='{column_name}'"
+    elif db_dialect == SQLITE:
+        sql_query = f"SELECT typeof('{column_name}') as data_type FROM '{table_name}' LIMIT 1"
     else:
-        sql_query = "SELECT `data_type` FROM `information_schema`.`columns` WHERE `table_name`='" + table_name + \
-                    "' AND `column_name`='" + column_name + "'"
+        sql_query = f"SELECT `data_type` FROM `information_schema`.`columns` " \
+                    f"WHERE `table_name`='{table_name}' AND `column_name`='{column_name}'"
         sql_query = _replace_query_enclosing_characters(sql_query, db_dialect)
 
-    try:
-        query_results_df = pd.read_sql(sql_query, con=db_connection)
-    except:
-        raise Exception('Query [' + sql_query + '] has failed to execute.')
+    query_results_df = pd.read_sql(sql_query, con=db_connection)
 
-    data_type = ''
     if 'data_type' in query_results_df.columns and len(query_results_df) == 1:
         data_type = query_results_df['data_type'][0]
     elif 'DATA_TYPE' in query_results_df.columns and len(query_results_df) == 1:
         data_type = query_results_df['DATA_TYPE'][0]
-
-    if data_type.upper() in SQL_RDF_DATATYPE:
-        return SQL_RDF_DATATYPE[data_type.upper()]
     else:
         return None
 
+    data_type = data_type.upper()
+    for k, v in SQL_RDF_DATATYPE.items():
+        if k in data_type:
+            return v
+    return None
+
 
 def get_rdb_reference_datatype(config, mapping_rule, reference):
     inferred_data_type = ''
@@ -155,10 +155,10 @@ def _build_sql_query(mapping_rule, references):
         query = 'SELECT '
         # query = query + 'DISTINCT ' # TODO: is this more efficient?
         for reference in references:
-            query = query + '`' + reference + '`, '
-        query = query[:-2] + ' FROM `' + mapping_rule['tablename'] + '` WHERE '
+            query = f"{query}`{reference}`, "
+        query = f"{query[:-2]} FROM `{mapping_rule['tablename']}` WHERE "
         for reference in references:
-            query = query + '`' + reference + '` IS NOT NULL AND '
+            query = f"{query} `{reference}` IS NOT NULL AND "
         query = query[:-5]
     else:
         query = None
@@ -168,11 +168,14 @@ def _build_sql_query(mapping_rule, references):
 
 def get_sql_data(config, mapping_rule, references):
     sql_query = _build_sql_query(mapping_rule, references)
+    if sql_query is None:
+        # in case all term maps are constants e.g. R2RML test case R2RMLTC0006a
+        return pd.DataFrame(columns=references)
+
     db_connection, db_dialect = _relational_db_connection(config, mapping_rule['source_name'])
     sql_query = _replace_query_enclosing_characters(sql_query, db_dialect)
 
-    if sql_query is not None:
-        logging.debug('SQL query for mapping rule `' + str(mapping_rule['id']) + '`: [' + sql_query + ']')
+    logging.debug(f"SQL query for mapping rule `{mapping_rule['id']}`: [{sql_query}]")
 
     result_chunks = pd.read_sql(sql_query,
                                 con=db_connection,
