@@ -11,12 +11,13 @@ __email__ = "arenas.guerrero.julian@outlook.com"
 ##############################################################################
 
 MAPPINGS_DATAFRAME_COLUMNS = [
-    'source_name', 'triples_map_id', 'data_source', 'object_map', 'iterator', 'tablename', 'query',
-    'subject_template', 'subject_reference', 'subject_constant', 'subject_rdf_class', 'subject_termtype',
+    'source_name', 'triples_map_id', 'data_source', 'subject_map', 'object_map', 'iterator', 'tablename', 'query',
+    'subject_template', 'subject_reference', 'subject_constant', 'subject_quoted', 'subject_termtype',
     'graph_constant', 'graph_reference', 'graph_template',
     'predicate_constant', 'predicate_template', 'predicate_reference',
-    'object_constant', 'object_template', 'object_reference', 'object_termtype', 'object_datatype', 'object_language',
-    'object_parent_triples_map', 'join_conditions'
+    'object_constant', 'object_template', 'object_reference', 'object_quoted',
+    'object_termtype', 'object_datatype', 'object_language',
+    'object_parent_triples_map', 'subject_join_conditions', 'object_join_conditions'
 ]
 
 
@@ -29,19 +30,19 @@ MAPPING_PARSING_QUERY = """
     # developed by members of the Scientific Data Management Group at TIB. Its development has been coordinated and
     # supervised by Maria-Esther Vidal. The implementation has been done by Enrique Iglesias and Guillermo Betancourt
     # under the supervision of David Chaves-Fraga, Samaneh Jozashoori, and Kemele Endris.
-    # It has been partially modified by Julián Arenas-Guerrero, PhD student at the Ontology Engineering Group (OEG)
+    # It has been modified by Julián Arenas-Guerrero, PhD student at the Ontology Engineering Group (OEG)
     # in Universidad Politécnica de Madrid (UPM).
 
     prefix rr: <http://www.w3.org/ns/r2rml#>
     prefix rml: <http://semweb.mmlab.be/ns/rml#>
 
     SELECT DISTINCT
-        ?triples_map_id ?data_source ?iterator ?tablename ?query ?object_map
-        ?subject_template ?subject_reference ?subject_constant
-        ?subject_rdf_class ?subject_termtype
+        ?triples_map_id ?data_source ?iterator ?tablename ?query ?subject_map ?object_map
+        ?subject_template ?subject_reference ?subject_constant ?subject_quoted ?subject_termtype
         ?graph_constant ?graph_reference ?graph_template
         ?predicate_constant ?predicate_template ?predicate_reference
-        ?object_constant ?object_template ?object_reference ?object_termtype ?object_datatype ?object_language
+        ?object_constant ?object_template ?object_reference ?object_quoted
+        ?object_termtype ?object_datatype ?object_language
         ?object_parent_triples_map
 
     WHERE {
@@ -53,12 +54,12 @@ MAPPING_PARSING_QUERY = """
 
     # Subject -------------------------------------------------------------------------
         OPTIONAL {
-            ?triples_map_id rr:subjectMap ?_subject_map .
-            OPTIONAL { ?_subject_map rr:template ?subject_template . }
-            OPTIONAL { ?_subject_map rml:reference ?subject_reference . }
-            OPTIONAL { ?_subject_map rr:constant ?subject_constant . }
-            OPTIONAL { ?_subject_map rr:class ?subject_rdf_class . }
-            OPTIONAL { ?_subject_map rr:termType ?subject_termtype . }
+            ?triples_map_id rml:subjectMap ?subject_map .
+            OPTIONAL { ?subject_map rr:template ?subject_template . }
+            OPTIONAL { ?subject_map rml:reference ?subject_reference . }
+            OPTIONAL { ?subject_map rr:constant ?subject_constant . }
+            OPTIONAL { ?subject_map rml:quotedTriplesMap ?subject_quoted . }
+            OPTIONAL { ?subject_map rr:termType ?subject_termtype . }
         }
 
     # Predicate -----------------------------------------------------------------------
@@ -79,28 +80,36 @@ MAPPING_PARSING_QUERY = """
 
     # Object --------------------------------------------------------------------------
             OPTIONAL {
-                ?_predicate_object_map rr:objectMap ?object_map .
+                ?_predicate_object_map rml:objectMap ?object_map .
+            }
+            OPTIONAL {
+                ?_predicate_object_map rml:objectMap ?object_map .
+                ?object_map rml:quotedTriplesMap ?object_quoted .
+                OPTIONAL { ?object_map rr:termType ?object_termtype . }
+            }
+            OPTIONAL {
+                ?_predicate_object_map rml:objectMap ?object_map .
                 ?object_map rr:constant ?object_constant .
                 OPTIONAL { ?object_map rr:termType ?object_termtype . }
                 OPTIONAL { ?object_map rr:datatype ?object_datatype . }
                 OPTIONAL { ?object_map rr:language ?object_language . }
             }
             OPTIONAL {
-                ?_predicate_object_map rr:objectMap ?object_map .
+                ?_predicate_object_map rml:objectMap ?object_map .
                 ?object_map rr:template ?object_template .
                 OPTIONAL { ?object_map rr:termType ?object_termtype . }
                 OPTIONAL { ?object_map rr:datatype ?object_datatype . }
                 OPTIONAL { ?object_map rr:language ?object_language . }
             }
             OPTIONAL {
-                ?_predicate_object_map rr:objectMap ?object_map .
+                ?_predicate_object_map rml:objectMap ?object_map .
                 ?object_map rml:reference ?object_reference .
                 OPTIONAL { ?object_map rr:termType ?object_termtype . }
                 OPTIONAL { ?object_map rr:datatype ?object_datatype . }
                 OPTIONAL { ?object_map rr:language ?object_language . }
             }
             OPTIONAL {
-                ?_predicate_object_map rr:objectMap ?object_map .
+                ?_predicate_object_map rml:objectMap ?object_map .
                 ?object_map rr:parentTriplesMap ?object_parent_triples_map .
                 OPTIONAL { ?object_map rr:termType ?object_termtype . }
             }
@@ -124,9 +133,9 @@ MAPPING_PARSING_QUERY = """
 JOIN_CONDITION_PARSING_QUERY = """
     prefix rr: <http://www.w3.org/ns/r2rml#>
 
-    SELECT DISTINCT ?object_map ?join_condition ?child_value ?parent_value
+    SELECT DISTINCT ?term_map ?join_condition ?child_value ?parent_value
     WHERE {
-        ?object_map rr:joinCondition ?join_condition .
+        ?term_map rr:joinCondition ?join_condition .
         ?join_condition rr:child ?child_value;
                         rr:parent ?parent_value.
     }
