@@ -30,15 +30,15 @@ def _mapping_to_rml(mapping_graph):
     mapping_graph.bind('ql', rdflib.term.URIRef(QL_NAMESPACE))
 
     # add reference formulation and sql version for RDB sources
-    query = 'SELECT ?logical_source ?x WHERE { ?logical_source <' + R2RML_TABLE_NAME + '> ?x . } '
+    query = f'SELECT ?logical_source ?x WHERE {{ ?logical_source <{R2RML_TABLE_NAME}> ?x . }} '
     for logical_source, _ in mapping_graph.query(query):
         mapping_graph.add((logical_source, rdflib.term.URIRef(R2RML_SQL_VERSION), rdflib.term.URIRef(R2RML_SQL2008)))
-    query = 'SELECT ?logical_source ?x WHERE { ?logical_source <' + R2RML_SQL_QUERY + '> ?x . } '
+    query = f'SELECT ?logical_source ?x WHERE {{ ?logical_source <{R2RML_SQL_QUERY}> ?x . }} '
     for logical_source, _ in mapping_graph.query(query):
         mapping_graph.add((logical_source, rdflib.term.URIRef(R2RML_SQL_VERSION), rdflib.term.URIRef(R2RML_SQL2008)))
         mapping_graph.add((logical_source, rdflib.term.URIRef(RML_REFERENCE_FORMULATION), rdflib.term.URIRef(QL_CSV)))
 
-    # replace R2RML predicates with the equivalent RML predicates
+    # replace R2RML properties with the equivalent RML properties
     mapping_graph = replace_predicates_in_graph(mapping_graph, R2RML_LOGICAL_TABLE, RML_LOGICAL_SOURCE)
     mapping_graph = replace_predicates_in_graph(mapping_graph, R2RML_SQL_QUERY, RML_QUERY)
     mapping_graph = replace_predicates_in_graph(mapping_graph, R2RML_COLUMN, RML_REFERENCE)
@@ -50,18 +50,30 @@ def _mapping_to_rml(mapping_graph):
     return mapping_graph
 
 
+def _mapping_to_rml_star(mapping_graph):
+    """
+        Replaces RML rules in the graph with the corresponding RML-star rules.
+    """
+
+    # replace RML properties with the equivalent RML-star properties
+    mapping_graph = replace_predicates_in_graph(mapping_graph, R2RML_SUBJECT_MAP, RML_STAR_SUBJECT_MAP)
+    mapping_graph = replace_predicates_in_graph(mapping_graph, R2RML_OBJECT_MAP, RML_STAR_OBJECT_MAP)
+
+    return mapping_graph
+
+
 def _expand_constant_shortcut_properties(mapping_graph):
     """
     Expand constant shortcut properties rr:subject, rr:predicate, rr:object and rr:graph.
     See R2RML specification (https://www.w3.org/2001/sw/rdb2rdf/r2rml/#constant).
     """
 
-    constant_properties = [R2RML_SUBJECT_MAP, R2RML_PREDICATE_MAP, R2RML_OBJECT_MAP, R2RML_GRAPH_MAP]
+    constant_properties = [RML_STAR_SUBJECT_MAP, R2RML_PREDICATE_MAP, RML_STAR_OBJECT_MAP, R2RML_GRAPH_MAP]
     constant_shortcuts = [R2RML_SUBJECT_CONSTANT_SHORTCUT, R2RML_PREDICATE_CONSTANT_SHORTCUT,
                           R2RML_OBJECT_CONSTANT_SHORTCUT, R2RML_GRAPH_CONSTANT_SHORTCUT]
 
     for constant_property, constant_shortcut in zip(constant_properties, constant_shortcuts):
-        for s, o in mapping_graph.query('SELECT ?s ?o WHERE {?s <' + constant_shortcut + '> ?o .}'):
+        for s, o in mapping_graph.query(f'SELECT ?s ?o WHERE {{?s <{constant_shortcut}> ?o .}}'):
             blanknode = rdflib.BNode()
             mapping_graph.add((s, rdflib.term.URIRef(constant_property), blanknode))
             mapping_graph.add((blanknode, rdflib.term.URIRef(R2RML_CONSTANT), o))
@@ -77,13 +89,13 @@ def _rdf_class_to_pom(mapping_graph):
     """
 
     query = 'SELECT ?tm ?c WHERE { ' \
-            '?tm <' + R2RML_SUBJECT_MAP + '> ?sm . ' \
-            '?sm <' + R2RML_CLASS + '> ?c . }'
+            f'?tm <{RML_STAR_SUBJECT_MAP}> ?sm . ' \
+            f'?sm <{R2RML_CLASS}> ?c . }}'
     for tm, c in mapping_graph.query(query):
         blanknode = rdflib.BNode()
         mapping_graph.add((tm, rdflib.term.URIRef(R2RML_PREDICATE_OBJECT_MAP), blanknode))
-        mapping_graph.add((blanknode, rdflib.term.URIRef(R2RML_OBJECT_CONSTANT_SHORTCUT), c))
         mapping_graph.add((blanknode, rdflib.term.URIRef(R2RML_PREDICATE_CONSTANT_SHORTCUT), rdflib.RDF.type))
+        mapping_graph.add((blanknode, rdflib.term.URIRef(R2RML_OBJECT_CONSTANT_SHORTCUT), c))
 
     mapping_graph.remove((None, rdflib.term.URIRef(R2RML_CLASS), None))
 
@@ -97,16 +109,16 @@ def _subject_graph_maps_to_pom(mapping_graph):
 
     # add the graph maps in the subject maps to every predicate object map of the subject maps
     query = 'SELECT ?sm ?gm ?pom WHERE { ' \
-            '?tm <' + R2RML_SUBJECT_MAP + '> ?sm . ' \
-            '?sm <' + R2RML_GRAPH_MAP + '> ?gm . ' \
-            '?tm <' + R2RML_PREDICATE_OBJECT_MAP + '> ?pom . }'
+            f'?tm <{RML_STAR_SUBJECT_MAP}> ?sm . ' \
+            f'?sm <{R2RML_GRAPH_MAP}> ?gm . ' \
+            f'?tm <{R2RML_PREDICATE_OBJECT_MAP}> ?pom . }}'
     for sm, gm, pom in mapping_graph.query(query):
         mapping_graph.add((pom, rdflib.term.URIRef(R2RML_GRAPH_MAP), gm))
 
     # remove the graph maps from the subject maps
     query = 'SELECT ?sm ?gm WHERE { ' \
-            '?tm <' + R2RML_SUBJECT_MAP + '> ?sm . ' \
-            '?sm <' + R2RML_GRAPH_MAP + '> ?gm . }'
+            f'?tm <{RML_STAR_SUBJECT_MAP}> ?sm . ' \
+            f'?sm <{R2RML_GRAPH_MAP}> ?gm . }}'
     for sm, gm in mapping_graph.query(query):
         mapping_graph.remove((sm, rdflib.term.URIRef(R2RML_GRAPH_MAP), gm))
 
@@ -119,8 +131,8 @@ def _complete_pom_with_default_graph(mapping_graph):
     """
 
     query = 'SELECT DISTINCT ?tm ?pom WHERE { ' \
-            '?tm <' + R2RML_PREDICATE_OBJECT_MAP + '> ?pom . ' \
-            'OPTIONAL { ?pom <' + R2RML_GRAPH_MAP + '> ?gm . } . ' \
+            f'?tm <{R2RML_PREDICATE_OBJECT_MAP}> ?pom . ' \
+            f'OPTIONAL {{ ?pom <{R2RML_GRAPH_MAP}> ?gm . }} . ' \
             'FILTER ( !bound(?gm) ) }'
     for tm, pom in mapping_graph.query(query):
         blanknode = rdflib.BNode()
@@ -136,38 +148,46 @@ def _complete_termtypes(mapping_graph):
     (https://www.w3.org/2001/sw/rdb2rdf/r2rml/#termtype).
     """
 
+    # add missing RDF-star triples termtypes (in the subject and object maps)
+    query = 'SELECT DISTINCT ?term_map ?quoted_triples_map WHERE { ' \
+            f'?term_map <{RML_STAR_QUOTED_TRIPLES_MAP}> ?quoted_triples_map . ' \
+            f'OPTIONAL {{ ?term_map <{R2RML_TERM_TYPE}> ?termtype . }} . ' \
+            'FILTER ( !bound(?termtype) ) }'
+    for term_map, _ in mapping_graph.query(query):
+        mapping_graph.add((term_map, rdflib.term.URIRef(R2RML_TERM_TYPE), rdflib.term.URIRef(RML_STAR_RDF_STAR_TRIPLE)))
+
     # add missing blanknode termtypes in the constant-valued object maps
     query = 'SELECT DISTINCT ?term_map ?constant WHERE { ' \
-            '?term_map <' + R2RML_CONSTANT + '> ?constant . ' \
-            'OPTIONAL { ?term_map <' + R2RML_TERM_TYPE + '> ?termtype . } . ' \
+            f'?term_map <{R2RML_CONSTANT}> ?constant . ' \
+            f'OPTIONAL {{ ?term_map <{R2RML_TERM_TYPE}> ?termtype . }} . ' \
             'FILTER ( !bound(?termtype) && isBlank(?constant) ) }'
     for term_map, _ in mapping_graph.query(query):
         mapping_graph.add((term_map, rdflib.term.URIRef(R2RML_TERM_TYPE), rdflib.term.URIRef(R2RML_BLANK_NODE)))
 
     # add missing literal termtypes in the constant-valued object maps
     query = 'SELECT DISTINCT ?term_map ?constant WHERE { ' \
-            '?term_map <' + R2RML_CONSTANT + '> ?constant . ' \
-            'OPTIONAL { ?term_map <' + R2RML_TERM_TYPE + '> ?termtype . } . ' \
+            f'?term_map <{R2RML_CONSTANT}> ?constant . ' \
+            f'OPTIONAL {{ ?term_map <{R2RML_TERM_TYPE}> ?termtype . }} . ' \
             'FILTER ( !bound(?termtype) && isLiteral(?constant) ) }'
     for term_map, _ in mapping_graph.query(query):
         mapping_graph.add((term_map, rdflib.term.URIRef(R2RML_TERM_TYPE), rdflib.term.URIRef(R2RML_LITERAL)))
 
     # add missing literal termtypes in the object maps
     query = 'SELECT DISTINCT ?om ?pom WHERE { ' \
-            '?pom <' + R2RML_OBJECT_MAP + '> ?om . ' \
-            'OPTIONAL { ?om <' + R2RML_TERM_TYPE + '> ?termtype . } . ' \
-            'OPTIONAL { ?om <' + RML_REFERENCE + '> ?column . } . ' \
-            'OPTIONAL { ?om <' + R2RML_LANGUAGE + '> ?language . } . ' \
-            'OPTIONAL { ?om <' + R2RML_DATATYPE + '> ?datatype . } . ' \
+            f'?pom <{RML_STAR_OBJECT_MAP}> ?om . ' \
+            f'OPTIONAL {{ ?om <{R2RML_TERM_TYPE}> ?termtype . }} . ' \
+            f'OPTIONAL {{ ?om <{RML_REFERENCE}> ?column . }} . ' \
+            f'OPTIONAL {{ ?om <{R2RML_LANGUAGE}> ?language . }} . ' \
+            f'OPTIONAL {{ ?om <{R2RML_DATATYPE}> ?datatype . }} . ' \
             'FILTER ( !bound(?termtype) && ( bound(?column) || bound(?language) || bound(?datatype) ) ) }'
     for om, _ in mapping_graph.query(query):
         mapping_graph.add((om, rdflib.term.URIRef(R2RML_TERM_TYPE), rdflib.term.URIRef(R2RML_LITERAL)))
 
     # now all missing termtypes are IRIs
-    for term_map_property in [R2RML_SUBJECT_MAP, R2RML_PREDICATE_MAP, R2RML_OBJECT_MAP, R2RML_GRAPH_MAP]:
+    for term_map_property in [RML_STAR_SUBJECT_MAP, R2RML_PREDICATE_MAP, RML_STAR_OBJECT_MAP, R2RML_GRAPH_MAP]:
         query = 'SELECT DISTINCT ?term_map ?x WHERE { ' \
-                '?x <' + term_map_property + '> ?term_map . ' \
-                'OPTIONAL { ?term_map <' + R2RML_TERM_TYPE + '> ?termtype . } . ' \
+                f'?x <{term_map_property}> ?term_map . ' \
+                f'OPTIONAL {{ ?term_map <{R2RML_TERM_TYPE}> ?termtype . }} . ' \
                 'FILTER ( !bound(?termtype) ) }'
         for term_map, _ in mapping_graph.query(query):
             mapping_graph.add((term_map, rdflib.term.URIRef(R2RML_TERM_TYPE), rdflib.term.URIRef(R2RML_IRI)))
@@ -185,15 +205,7 @@ def _remove_string_datatypes(mapping_graph):
     return mapping_graph
 
 
-def _complete_rml_classes(mapping_graph):
-    """
-    TODO
-    """
-
-    return mapping_graph
-
-
-def _get_join_object_maps_join_conditions(join_query_results):
+def _get_join_conditions_dict(join_query_results):
     """
     Creates a dictionary with the results of the JOIN_CONDITION_PARSING_QUERY. The keys are the identifiers of the
     child triples maps of the join condition. The values of the dictionary are in turn other dictionaries with two
@@ -204,38 +216,47 @@ def _get_join_object_maps_join_conditions(join_query_results):
 
     for join_condition in join_query_results:
         # add the child triples map identifier if it is not in the dictionary
-        if join_condition.object_map not in join_conditions_dict:
-            join_conditions_dict[join_condition.object_map] = {}
+        if join_condition.term_map not in join_conditions_dict:
+            join_conditions_dict[join_condition.term_map] = {}
 
         # add the new join condition (note that several join conditions can apply in a join)
-        join_conditions_dict[join_condition.object_map][str(join_condition.join_condition)] = \
+        join_conditions_dict[join_condition.term_map][str(join_condition.join_condition)] = \
             {'child_value': str(join_condition.child_value), 'parent_value': str(join_condition.parent_value)}
 
     return join_conditions_dict
 
 
-def _transform_mappings_into_dataframe(mapping_query_results, join_query_results, section_name):
+def _transform_mappings_into_dataframe(mapping_graph, section_name):
     """
     Builds a Pandas DataFrame from the results obtained from MAPPING_PARSING_QUERY and
     JOIN_CONDITION_PARSING_QUERY for one source.
     """
 
+    # parse the mappings with the parsing queries
+    mapping_query_results = mapping_graph.query(MAPPING_PARSING_QUERY)
+    join_query_results = mapping_graph.query(JOIN_CONDITION_PARSING_QUERY)
+
     # mapping rules in graph to DataFrame
     source_mappings_df = pd.DataFrame(mapping_query_results.bindings)
     source_mappings_df.columns = source_mappings_df.columns.map(str)
+    source_mappings_df = source_mappings_df.reindex(columns=MAPPINGS_DATAFRAME_COLUMNS)
 
     # process mapping rules with joins
     # create a dict with child triples maps in the keys and its join conditions in the values
-    join_conditions_dict = _get_join_object_maps_join_conditions(join_query_results)
+    join_conditions_dict = _get_join_conditions_dict(join_query_results)
     # map the dict with the join conditions to the mapping rules in the DataFrame
-    source_mappings_df['join_conditions'] = source_mappings_df['object_map'].map(join_conditions_dict)
+    source_mappings_df['object_join_conditions'] = source_mappings_df['object_map'].map(join_conditions_dict)
+    source_mappings_df['subject_join_conditions'] = source_mappings_df['subject_map'].map(join_conditions_dict)
     # needed for later hashing the dataframe
-    source_mappings_df['join_conditions'] = source_mappings_df['join_conditions'].where(
-        pd.notna(source_mappings_df['join_conditions']), '')
+    source_mappings_df['object_join_conditions'] = source_mappings_df['object_join_conditions'].where(
+        pd.notna(source_mappings_df['object_join_conditions']), '')
+    source_mappings_df['subject_join_conditions'] = source_mappings_df['subject_join_conditions'].where(
+        pd.notna(source_mappings_df['subject_join_conditions']), '')
     # convert the join condition dicts to string (can later be converted back to dict)
-    source_mappings_df['join_conditions'] = source_mappings_df['join_conditions'].astype(str)
-    # object_map column no longer needed, remove it
-    source_mappings_df = source_mappings_df.drop('object_map', axis=1)
+    source_mappings_df['object_join_conditions'] = source_mappings_df['object_join_conditions'].astype(str)
+    source_mappings_df['subject_join_conditions'] = source_mappings_df['subject_join_conditions'].astype(str)
+    # object_map and subject_map columns no longer needed, remove them
+    source_mappings_df = source_mappings_df.drop(['subject_map', 'object_map'], axis=1)
 
     # link the mapping rules to their data source name
     source_mappings_df['source_name'] = section_name
@@ -276,6 +297,41 @@ def _get_valid_template_identifiers(template):
     return template
 
 
+def _validate_termtypes(mapping_graph):
+    query = 'SELECT DISTINCT ?termtype ?pm WHERE { ' \
+            f'?pom <{R2RML_PREDICATE_MAP}> ?pm . ' \
+            f'?pm <{R2RML_TERM_TYPE}> ?termtype . }}'
+    predicate_termtypes = [str(termtype) for termtype, _ in mapping_graph.query(query)]
+    if not (set(predicate_termtypes) <= {R2RML_IRI}):
+        raise ValueError(f'Found an invalid predicate termtype. Found values {predicate_termtypes}. '
+                         f'Predicate maps must be {R2RML_IRI}.')
+
+    query = 'SELECT DISTINCT ?termtype ?gm WHERE { ' \
+            f'?pom <{R2RML_GRAPH_MAP}> ?gm . ' \
+            f'?gm <{R2RML_TERM_TYPE}> ?termtype . }}'
+    graph_termtypes = [str(termtype) for termtype, _ in mapping_graph.query(query)]
+    if not (set(graph_termtypes) <= {R2RML_IRI}):
+        raise ValueError(f'Found an invalid graph termtype. Found values {graph_termtypes}. '
+                         f'Graph maps must be {R2RML_IRI}.')
+
+    query = 'SELECT DISTINCT ?termtype ?sm WHERE { ' \
+            f'?tm <{R2RML_SUBJECT_MAP}> ?sm . ' \
+            f'?sm <{R2RML_TERM_TYPE}> ?termtype . }}'
+    subject_termtypes = [str(termtype) for termtype, _ in mapping_graph.query(query)]
+    if not (set(subject_termtypes) <= {R2RML_IRI, R2RML_BLANK_NODE, RML_STAR_RDF_STAR_TRIPLE}):
+        raise ValueError(f'Found an invalid subject termtype. Found values {subject_termtypes}. '
+                         f'Subject maps must be {R2RML_IRI}, {R2RML_BLANK_NODE} or {RML_STAR_RDF_STAR_TRIPLE}.')
+
+    query = 'SELECT DISTINCT ?termtype ?om WHERE { ' \
+            f'?pom <{R2RML_OBJECT_MAP}> ?om . ' \
+            f'?om <{R2RML_TERM_TYPE}> ?termtype . }}'
+    object_termtypes = [str(termtype) for termtype, _ in mapping_graph.query(query)]
+    if not (set(object_termtypes) <= {R2RML_IRI, R2RML_BLANK_NODE, R2RML_LITERAL, RML_STAR_RDF_STAR_TRIPLE}):
+        raise ValueError(f'Found an invalid object termtype. Found values {object_termtypes}. '
+                         f'Object maps must be {R2RML_IRI}, {R2RML_BLANK_NODE}, {R2RML_LITERAL} '
+                         f'or {RML_STAR_RDF_STAR_TRIPLE}.')
+
+
 class MappingParser:
 
     def __init__(self, config):
@@ -298,7 +354,7 @@ class MappingParser:
 
         self.validate_mappings()
 
-        logging.info(str(len(self.mappings_df)) + ' mapping rules retrieved.')
+        logging.info(f'{len(self.mappings_df)} mapping rules retrieved.')
 
         # generate mapping partitions
         mapping_partitioner = MappingPartitioner(self.mappings_df, self.config)
@@ -347,6 +403,8 @@ class MappingParser:
 
         # convert R2RML rules to RML, so that we can assume RML for parsing
         mapping_graph = _mapping_to_rml(mapping_graph)
+        # convert RML rules to RML-star, so that we can assume RML-star for parsing
+        mapping_graph = _mapping_to_rml_star(mapping_graph)
         # convert rr:class to new POMs
         mapping_graph = _rdf_class_to_pom(mapping_graph)
         # expand constant shortcut properties rr:subject, rr:predicate, rr:object and rr:graph
@@ -359,15 +417,11 @@ class MappingParser:
         mapping_graph = _complete_termtypes(mapping_graph)
         # remove xsd:string data types as it is equivalent to not specifying any data type
         mapping_graph = _remove_string_datatypes(mapping_graph)
-        # add rdf:type RML classes
-        mapping_graph = _complete_rml_classes(mapping_graph)
-
-        # parse the mappings with the parsing queries
-        mapping_query_results = mapping_graph.query(MAPPING_PARSING_QUERY)
-        join_query_results = mapping_graph.query(JOIN_CONDITION_PARSING_QUERY)
+        # check termtypes are correct
+        _validate_termtypes(mapping_graph)
 
         # convert the SPARQL result set with the parsed mappings to DataFrame
-        return _transform_mappings_into_dataframe(mapping_query_results, join_query_results, section_name)
+        return _transform_mappings_into_dataframe(mapping_graph, section_name)
 
     def _preprocess_mappings(self):
         # start by removing duplicated triples
@@ -444,16 +498,18 @@ class MappingParser:
                 mapping_rule['object_reference'])
 
             # if join_condition is not null and it is not empty
-            if pd.notna(mapping_rule['join_conditions']) and mapping_rule['join_conditions']:
-                join_conditions = eval(mapping_rule['join_conditions'])
-                for key, value in join_conditions.items():
-                    join_conditions[key]['child_value'] = _get_undelimited_identifier(
-                        join_conditions[key]['child_value'])
-                    join_conditions[key]['parent_value'] = _get_undelimited_identifier(
-                        join_conditions[key]['parent_value'])
-                    self.mappings_df.at[i, 'join_conditions'] = str(join_conditions)
+            for join_conditions_pos in ['subject_join_conditions', 'object_join_conditions']:
+                if pd.notna(mapping_rule[join_conditions_pos]) and mapping_rule[join_conditions_pos]:
+                    join_conditions = eval(mapping_rule[join_conditions_pos])
+                    for key, value in join_conditions.items():
+                        join_conditions[key]['child_value'] = _get_undelimited_identifier(
+                            join_conditions[key]['child_value'])
+                        join_conditions[key]['parent_value'] = _get_undelimited_identifier(
+                            join_conditions[key]['parent_value'])
+                        self.mappings_df.at[i, join_conditions_pos] = str(join_conditions)
 
     def _remove_self_joins_from_mappings(self):
+        # TODO: remove (when possible) join conditions in quoted triples maps
 
         # because RDB has no rml:source, use source_name for rml:source to facilitate self-join elimination
         self.mappings_df.loc[self.mappings_df['source_type'] == RDB, 'data_source'] = self.mappings_df['source_name']
@@ -472,7 +528,7 @@ class MappingParser:
                     remove_join = True
                     # check that all conditions in the join condition have the same references
                     try:
-                        join_conditions = eval(mapping_rule['join_conditions'])
+                        join_conditions = eval(mapping_rule['object_join_conditions'])
                         for key, join_condition in join_conditions.items():
                             if join_condition['child_value'] != join_condition['parent_value']:
                                 remove_join = False
@@ -482,13 +538,13 @@ class MappingParser:
 
                     if remove_join:
                         self.mappings_df.at[i, 'object_parent_triples_map'] = ''
-                        self.mappings_df.at[i, 'join_conditions'] = ''
+                        self.mappings_df.at[i, 'object_join_conditions'] = ''
                         self.mappings_df.at[i, 'object_constant'] = parent_triples_map_rule.at['subject_constant']
                         self.mappings_df.at[i, 'object_template'] = parent_triples_map_rule.at['subject_template']
                         self.mappings_df.at[i, 'object_reference'] = parent_triples_map_rule.at['subject_reference']
                         self.mappings_df.at[i, 'object_termtype'] = parent_triples_map_rule.at['subject_termtype']
 
-                        logging.debug('Removed self-join from mapping rule `' + str(mapping_rule['id']) + '`.')
+                        logging.debug(f"Removed self-join from mapping rule `{mapping_rule['id']}`.")
 
     def _infer_datatypes(self):
         """
@@ -519,36 +575,21 @@ class MappingParser:
 
                     self.mappings_df.at[i, 'object_datatype'] = inferred_data_type
                     if pd.notna(mapping_rule['tablename']):
-                        logging.debug("`" + inferred_data_type + "` datatype inferred for column `" +
-                                      mapping_rule['object_reference'] + "` of table `" +
-                                      mapping_rule['tablename'] + "` in data source `" +
-                                      mapping_rule['source_name'] + "`.")
+                        logging.debug(f"`{inferred_data_type}` datatype inferred for column "
+                                      f"`{mapping_rule['object_reference']}` of table `{mapping_rule['tablename']}` "
+                                      f"in data source `{mapping_rule['source_name']}`.")
                     elif pd.notna(mapping_rule['query']):
-                        logging.debug("`" + inferred_data_type + "` datatype inferred for reference `" +
-                                      mapping_rule['object_reference'] + "` in query [" +
-                                      mapping_rule['query'] + "] in data source `" +
-                                      mapping_rule['source_name'] + "`.")
+                        logging.debug(f"`{inferred_data_type}` datatype inferred for reference "
+                                      f"`{mapping_rule['object_reference']}` in query [{mapping_rule['query']}] "
+                                      f"in data source `{mapping_rule['source_name']}`.")
 
     def validate_mappings(self):
         """
         Checks that the mapping rules in the input DataFrame are valid. If something is wrong in the mappings the
-        execution is stopped. Specifically it is checked that termtypes are correct, and that language tags and
+        execution is stopped. Specifically it is checked that language tags and
         datatypes are used properly. Also checks that different data sources do not have triples map with the same id.
         """
 
-        # check termtypes are correct (i.e. that they are rr:IRI, rr:BlankNode or rr:Literal and that subject map is
-        # not a rr:literal). Use subset operation
-        subject_termtypes = set([str(termtype) for termtype in set(self.mappings_df['subject_termtype'])])
-        if not (subject_termtypes <= {R2RML_IRI, R2RML_BLANK_NODE}):
-            raise ValueError('Found an invalid subject termtype. Found values ' + str(subject_termtypes) +
-                             '. Subject maps must be ' + R2RML_IRI + ' or ' + R2RML_BLANK_NODE + '.')
-
-        object_termtypes = set([str(termtype) for termtype in set(self.mappings_df['object_termtype'])])
-        if not (object_termtypes <= {R2RML_IRI, R2RML_BLANK_NODE, R2RML_LITERAL}):
-            raise ValueError('Found an invalid object termtype. Found values ' + str(object_termtypes) +
-                             '. Object maps must be ' + R2RML_IRI + ', ' + R2RML_BLANK_NODE + ' or ' +
-                             R2RML_LITERAL + '.')
-
         # if there is a datatype or language tag then the object map termtype must be a rr:Literal
         if len(self.mappings_df.loc[(self.mappings_df['object_termtype'] != R2RML_LITERAL) &
                                     pd.notna(self.mappings_df['object_datatype']) &
@@ -569,8 +610,8 @@ class MappingParser:
         for language_tag in language_tags:
             # in general, if the language subtag is longer than 3 characters it is not valid
             if len(language_tag.split('-')[0]) > 3:
-                raise ValueError('Found invalid language tag `' + language_tag +
-                                 '`. Language tags must be in the IANA Language Subtag Registry.')
+                raise ValueError(f'Found invalid language tag `{language_tag}`. '
+                                 'Language tags must be in the IANA Language Subtag Registry.')
 
         # check that a triples map id is not repeated in different data sources
         # Get unique source names and triples map identifiers
@@ -580,6 +621,6 @@ class MappingParser:
         # of those repeated identifiers
         repeated_triples_map_ids = [tm_id for tm_id in repeated_triples_map_ids]
         if len(repeated_triples_map_ids) > 0:
-            raise Exception('The following triples maps appear in more than one data source: ' +
-                            str(repeated_triples_map_ids) +
-                            '. Check the mapping files, one triple map cannot be repeated in different data sources.')
+            raise Exception('The following triples maps appear in more than one data source: '
+                            f'{repeated_triples_map_ids}. '
+                            'Check the mapping files, one triple map cannot be repeated in different data sources.')
