@@ -75,6 +75,9 @@ def _get_references_in_mapping_rule(mapping_rule, only_subject_map=False):
 def _materialize_template(results_df, template, config, columns_alias='', termtype=R2RML_IRI, language_tag='',
                           datatype=''):
     references = get_references_in_template(str(template))
+    # Curly braces that do not enclose column names MUST be escaped by a backslash character (“\”).
+    # This also applies to curly braces within column names.
+    template = template.replace('\\{', '{').replace('\\}', '}')
 
     if str(termtype).strip() == R2RML_IRI:
         results_df['triple'] = results_df['triple'] + '<'
@@ -90,13 +93,12 @@ def _materialize_template(results_df, template, config, columns_alias='', termty
             results_df['reference_results'] = results_df['reference_results'].apply(lambda x: remove_non_printable_characters(x))
 
         if str(termtype).strip() == R2RML_IRI:
-            # if all characters are to be encoded use falcon, which is faster
             if config.get_safe_percent_encoding():
                 results_df['reference_results'] = results_df['reference_results'].apply(lambda x: quote(x, safe=config.get_safe_percent_encoding()))
             else:
                 results_df['reference_results'] = results_df['reference_results'].apply(lambda x: encode_value(x))
         elif str(termtype).strip() == R2RML_LITERAL:
-            results_df['reference_results'] = results_df['reference_results'].str.replace('\\', '\\\\', regex=False).str.replace('\n', '\\n', regex=False).str.replace('\r', '\\r', regex=False).str.replace('\t', '\\t', regex=False).str.replace('\b', '\\b', regex=False).str.replace('\f', '\\f', regex=False).str.replace('\r', '\\r', regex=False).str.replace('"', '\\"', regex=False).str.replace("'", "\\'", regex=False)
+            results_df['reference_results'] = results_df['reference_results'].str.replace('\\', '\\\\', regex=False).str.replace('\n', '\\n', regex=False).str.replace('\t', '\\t', regex=False).str.replace('\b', '\\b', regex=False).str.replace('\f', '\\f', regex=False).str.replace('\r', '\\r', regex=False).str.replace('"', '\\"', regex=False).str.replace("'", "\\'", regex=False)
 
         splitted_template = template.split('{' + reference + '}')
         results_df['triple'] = results_df['triple'] + splitted_template[0] + results_df['reference_results']
@@ -129,7 +131,7 @@ def _materialize_reference(results_df, reference, config, columns_alias='', term
         results_df['reference_results'] = results_df['reference_results'].apply(lambda x: remove_non_printable_characters(x))
 
     if str(termtype).strip() == R2RML_LITERAL:
-        results_df['reference_results'] = results_df['reference_results'].str.replace('\\', '\\\\', regex=False).str.replace('\n', '\\n', regex=False).str.replace('\r', '\\r', regex=False).str.replace('\t', '\\t', regex=False).str.replace('\b', '\\b', regex=False).str.replace('\f', '\\f', regex=False).str.replace('\r', '\\r', regex=False).str.replace('"', '\\"', regex=False).str.replace("'", "\\'", regex=False)
+        results_df['reference_results'] = results_df['reference_results'].str.replace('\\', '\\\\', regex=False).str.replace('\n', '\\n', regex=False).str.replace('\t', '\\t', regex=False).str.replace('\b', '\\b', regex=False).str.replace('\f', '\\f', regex=False).str.replace('\r', '\\r', regex=False).str.replace('"', '\\"', regex=False).str.replace("'", "\\'", regex=False)
         results_df['triple'] = results_df['triple'] + '"' + results_df['reference_results'] + '"'
         if pd.notna(language_tag):
             results_df['triple'] = results_df['triple'] + '@' + language_tag + ' '
@@ -138,11 +140,8 @@ def _materialize_reference(results_df, reference, config, columns_alias='', term
         else:
             results_df['triple'] = results_df['triple'] + ' '
     elif str(termtype).strip() == R2RML_IRI:
-        # if all characters are to be encoded use falcon, which is faster
-        if config.get_safe_percent_encoding():
-            results_df['reference_results'] = results_df['reference_results'].apply(lambda x: quote(x, safe=config.get_safe_percent_encoding()))
-        else:
-            results_df['reference_results'] = results_df['reference_results'].apply(lambda x: encode_value(x))
+        # it is assumed that the IRI values will be correct, and they are not percent encoded
+        results_df['reference_results'] = results_df['reference_results'].apply(lambda x: x.strip())
         results_df['triple'] = results_df['triple'] + '<' + results_df['reference_results'] + '> '
     elif str(termtype).strip() == R2RML_BLANK_NODE:
         results_df['triple'] = results_df['triple'] + '_:' + results_df['reference_results'] + ' '
@@ -304,8 +303,8 @@ def _materialize_mapping_partition(mapping_partition, subject_maps_df, config):
         start_time = time.time()
         triples.update(set(_materialize_mapping_rule(mapping_rule, subject_maps_df, config)))
 
-        logging.debug(str(len(triples)) + ' triples generated for mapping rule `' + str(
-            mapping_rule['id']) + '` in ' + get_delta_time(start_time) + ' seconds.')
+        logging.debug(f"{len(triples)} triples generated for mapping rule `{mapping_rule['id']}` "
+                      f"in {get_delta_time(start_time)} seconds.")
 
     triples_to_file(triples, config, mapping_partition.iloc[0]['mapping_partition'])
 
@@ -337,10 +336,10 @@ class Materializer:
         for mapping_partition in self.mapping_partitions:
             num_triples += _materialize_mapping_partition(mapping_partition, self.subject_maps_df, self.config)
 
-        logging.info('Number of triples generated in total: ' + str(num_triples) + '.')
+        logging.info(f'Number of triples generated in total: {num_triples}.')
 
     def materialize_concurrently(self):
-        logging.debug('Parallelizing with ' + str(self.config.get_number_of_processes()) + ' cores.')
+        logging.debug(f'Parallelizing with {self.config.get_number_of_processes()} cores.')
 
         pool = mp.Pool(self.config.get_number_of_processes())
         num_triples = sum(pool.starmap(_materialize_mapping_partition,
@@ -348,4 +347,4 @@ class Materializer:
         pool.close()
         pool.join()
 
-        logging.info('Number of triples generated in total: ' + str(num_triples) + '.')
+        logging.info(f'Number of triples generated in total: {num_triples}.')
