@@ -16,6 +16,7 @@ import numpy as np
 import pandas as pd
 
 from itertools import product
+from .constants import AUXILIAR_UNIQUE_REPLACING_STRING
 
 
 def configure_logger(logging_level, logging_file):
@@ -126,7 +127,13 @@ def get_references_in_template(template):
     Retrieves all reference identifiers in a template-valued term map. References are returned in order of appearance
     """
 
-    return re.findall('\\{([^}]+)', template)
+    # Curly braces that do not enclose column names MUST be escaped by a backslash character (“\”).
+    # This also applies to curly braces within column names.
+    template = template.replace('\\{', AUXILIAR_UNIQUE_REPLACING_STRING).replace('\\}', AUXILIAR_UNIQUE_REPLACING_STRING)
+    references = re.findall('\\{([^}]+)', template)
+    references = [reference.replace(AUXILIAR_UNIQUE_REPLACING_STRING, '\\{').replace(AUXILIAR_UNIQUE_REPLACING_STRING, '\\}') for reference in references]
+
+    return references
 
 
 def triples_to_file(triples, config, mapping_partition=''):
@@ -136,7 +143,7 @@ def triples_to_file(triples, config, mapping_partition=''):
 
     f = open(config.get_output_file_path(mapping_partition), 'a')
     for triple in triples:
-        f.write(triple + '.\n')
+        f.write(f'{triple}.\n')
     f.close()
 
 
@@ -178,7 +185,7 @@ def replace_predicates_in_graph(graph, predicate_to_remove, predicate_to_add):
     """
 
     # get the triples with the predicate to be replaced
-    r2_rml_sources_query = 'SELECT ?s ?o WHERE {?s <' + predicate_to_remove + '> ?o .}'
+    r2_rml_sources_query = f'SELECT ?s ?o WHERE {{?s <{predicate_to_remove}> ?o .}}'
     subjects_objects_matched = graph.query(r2_rml_sources_query)
 
     # for each triple to be replaced add a similar one (same subject and object) but with the new predicate
@@ -219,8 +226,8 @@ def get_references_in_join_condition(mapping_rule):
     parent_references = list()
 
     # if join_condition is not null and it is not empty
-    if pd.notna(mapping_rule['join_conditions']) and mapping_rule['join_conditions']:
-        join_conditions = eval(mapping_rule['join_conditions'])
+    if pd.notna(mapping_rule['object_join_conditions']) and mapping_rule['object_join_conditions']:
+        join_conditions = eval(mapping_rule['object_join_conditions'])
         for join_condition in join_conditions.values():
             references.append(join_condition['child_value'])
             parent_references.append(join_condition['parent_value'])
@@ -228,14 +235,6 @@ def get_references_in_join_condition(mapping_rule):
     return references, parent_references
 
 
-def remove_file_extension(file_path):
-    # only removes the last file extension (if there are multiple dots in file_path)
-    if len(os.path.splitext(file_path)) > 1:
-        return os.path.splitext(file_path)[0]
-
-    return file_path
-
-
 def normalize_oracle_identifier_casing(dataframe, references):
     """
     This renames the columns of a DataFrame generated when querying Oracle. This is necessary as Oracle identifier
